/*
 * $Id: EntryCountLimitedOnDemandStatsProducer.java 10244 2012-11-20 20:55:21Z another $
 * 
 * This file is part of the MoSKito software project
 * that is hosted at http://moskito.dev.java.net.
 * 
 * All MoSKito files are distributed under MIT License:
 * 
 * Copyright (c) 2006,2007 The MoSKito Project Team.
 * 
 * Permission is hereby granted, free of charge,
 * to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), 
 * to deal in the Software without restriction, 
 * including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit 
 * persons to whom the Software is furnished to do so, 
 * subject to the following conditions:
 * 
 * The above copyright notice and this permission notice
 * shall be included in all copies 
 * or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY
 * OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
 * LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS 
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
 * THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */	
package net.anotheria.moskito.core.dynamic;

import net.anotheria.moskito.core.producers.IStats;

/**
 * This implementation of the OnDemandStatsProducer has a hardcoded entry limit.
 */
public class EntryCountLimitedOnDemandStatsProducer<S extends IStats> extends OnDemandStatsProducer<S>{
	/**
	 * Limit for dynamically add-able entries.
	 */
	private int limit;

	public EntryCountLimitedOnDemandStatsProducer(String aProducerId, String aCategory, String aSubsystem, IOnDemandStatsFactory aStatsFactory, int aLimit){
		super(aProducerId, aCategory, aSubsystem, aStatsFactory);
		limit = aLimit;
	}
	
	public int getLimit() {
		return limit;
	}

	public void setLimit(int limit) {
		this.limit = limit;
	}
	
	@Override protected String getProducerNameExtension(){
		return "limited: "+limit;
	}

	@Override
	protected boolean limitForNewEntriesReached() {
		return getCachedStatsList().size()>limit;
	}
	
	@Override public String toString(){
		return super.toString()+" ("+getCachedStatsList().size()+" / "+limit+")";
	}
	
	
}
